bayespy.inference.vmp.nodes.deterministic.Deterministic.broadcasting_multiplier
===============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.deterministic

.. automethod:: Deterministic.broadcasting_multiplier